//
//  Test_qtdot.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_qtdot_h
#define BulletTest_Test_qtdot_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_qtdot(void);

#ifdef __cplusplus
}
#endif

#endif
